#!/bin/sh
#########################################################################
#  This script builds a list of file names in which to search for data  #
#  described in a control file made by the user_in script.		#
#									#
#  All of the paths set in environmental variable VSDB_DATA are		#
#  searched for each file required by the range of dates found in the	#
#  control file.  Date ranges are generated by FORTRAN program named	#
#  mkymrg_vsdb.								#
#									#
#  The output from this script is a file called vsdb_files_found	#
#  containing a list of complete paths to all files required by the	#
#  search conditions set in the control file.				#
#									#
#  The environmental variable VSDB_DATA contains the search paths	#
#  separated by : without any spaces.					#
#									#
#  The environmental variable VSDB_TEMP gives the location of a		#
#  temporary writeable disk to use as a workspace if the archived	#
#  files are compressed.						#
#									#
#  The environmental variable VSDB_DAY1 gives the lower bound for	#
#  data searches of indefinite beginning when no .first_date file	#
#  exists under $VSDB_DATA.  VSDB_DAY1 is of the form YYYYMMDDHHNN.	#
#									#
#  Log:									#
#  K. Brill/HPC		 3/03						#
#  K. Brill/HPC		 3/04	Screen files for .vsdb			#
#  K. Brill/HPC		11/05	Change "grep $fil" to "grep /$fil"	#
#  K. Brill/HPC      20081002   Initialize $dayone to 1998010100 and set#
#                               it to .first_date in path #1 if more	#
#                               than one path.				#
#  K. Brill/WPC      20130909   Do a separate search for duplicate files#
#				for each search path			#
#########################################################################

#  Get the name of the control file.

if [ $# -eq 0 ]; then
    echo " No control file name passed to bld_file_names"
    exit 1
fi

control_file=$1
if [ ! -s $control_file ]; then
    echo " $control_file does not exist."
    exit 1
fi

#  Get the search paths from environment.

dayone=1998010100
srch_paths=
wrd=1
np=0
echo $VSDB_DATA | grep ":" > /dev/null 2>&1
if [ $? -ne 0 ]; then
    srch_paths=$VSDB_DATA
    wrd=0
    if [ -s $srch_paths/.first_date ]; then
	dayone=`cat $srch_paths/.first_date`
    fi
fi
while [ $wrd -ne 0 ]; do
    np=`expr $np + 1`
    loc=`echo $VSDB_DATA | cut -d: -f$np`
    wrd=`echo $loc | wc -w`
    if [ $np -eq 1 ]; then
        dayone=`cat $loc/.first_date`
    fi
    if [ $wrd -ne 0 ]; then
	srch_paths="$srch_paths $loc"
	if [ $np -gt 1 ]; then
	    if [ -s $loc/.first_date ]; then
		day1=`cat $loc/.first_date`
		if [ $day1 -lt $dayone ]; then
		    dayone=$day1
		fi
	    fi
	fi
    fi
done
#################################################

#  Create PERL script for selecting files.

cat << EOF > mklist.prl
open ( YMD, "ymd.tbl" );
open ( OUT, ">files.list" );
while (<YMD>) {
    m/(\d{6})\d{2} (\d{6})/;
    \$date1 = \$1;
    \$date2 = \$2;
    m/(\d{8}) (\d{8})/;
    \$date3 = \$1;
    \$date4 = \$2;
    open ( FLS, "$$.fil" );
    while (<FLS>) {
	chop;
	if ( m/\D+(\d{8})/ ) {
	    if ( \$1 >= \$date3 && \$1 <= \$date4 ) {
		printf ( OUT "%s\n", \$_);
	    }
	}
	else {
	    m/\D+(\d{6})/;
	    if ( \$1 >= \$date1 && \$1 <= \$date2 ) {
		printf ( OUT "%s\n", \$_);
	    }
	}
    }
    close FLS;
}
EOF

chmod +x mklist.prl
PERL=`which perl`
if [ $? -ne 0 ]; then
    echo "The perl command (required) is not available."
    exit 1
fi
#################################################

# Generate list of model names and time ranges.

ymd=`date +%Y%m%d`
if [ $dayone = null ]; then
    dayone=$VSDB_DAY1
fi

mkymrg_vsdb << EOF
$control_file
$ymd
$dayone
EOF

sort -u vsdb_Ymd > ymd.tbl
modelist=`sort -u vsdb_models | tr '[A-Z]' '[a-z]'`
/bin/rm -f vsdb_models
nyymm=`echo $yymdlist | wc -w`

/bin/rm -f vsdb_files_found
/bin/rm -f vsdb_files

if [ ! -d $VSDB_TEMP/vsdb ]; then
    mkdir -p $VSDB_TEMP/vsdb
    chmod 777 $VSDB_TEMP/vsdb
else
    /bin/rm -rf $VSDB_TEMP/vsdb/*
fi

icnt_dups=0
for sp in $srch_paths; do
    echo " " > duplist
    for mdl in $modelist; do
	if [ -d ${sp}/$mdl ]; then
	    echo Creating file list from $sp/$mdl
	    /bin/ls -1 ${sp}/${mdl} | grep -e '^'${mdl}_ | grep -e '.vsdb$' -e '.vsdb.Z$' -e '.vsdb.gz$' > $$.fil
	    $PERL mklist.prl
	    /bin/rm -f $$.fil
	    files=`cat files.list`
	    /bin/rm -f files.list
	    for fil in $files; do
		grep /$fil duplist > /dev/null 2>&1
		if [ $? -ne 0 ]; then
		    echo $fil | grep ".Z" > /dev/null 2>&1
		    if [ $? -eq 0 ]; then
			cp ${sp}/${mdl}/${fil} $VSDB_TEMP/vsdb/.
			uncompress $VSDB_TEMP/vsdb/${fil}
			nc=`echo $fil | wc -c`
			nc=`expr $nc - 3`
			mdlfil=`echo $fil | cut -c1-$nc`
			echo $VSDB_TEMP/vsdb/${mdlfil} >> vsdb_files
			echo $VSDB_TEMP/vsdb/${mdlfil} >> duplist
			chmod a+w $VSDB_TEMP/vsdb/${mdlfil}
		    else
			echo $fil | grep ".gz" > /dev/null 2>&1
			if [ $? -eq 0 ]; then
			    cp ${sp}/${mdl}/${fil} $VSDB_TEMP/vsdb/.
			    gunzip $VSDB_TEMP/vsdb/${fil}
			    nc=`echo $fil | wc -c`
			    nc=`expr $nc - 4`
			    mdlfil=`echo $fil | cut -c1-$nc`
			    echo $VSDB_TEMP/vsdb/${mdlfil} >> vsdb_files
			    echo $VSDB_TEMP/vsdb/${mdlfil} >> duplist
			    chmod a+w $VSDB_TEMP/vsdb/${mdlfil}
			else
			    echo ${sp}/${mdl}/$fil >> vsdb_files
			    echo ${sp}/${mdl}/$fil >> duplist
			fi
		    fi
		else
		    icnt_dups=`expr $icnt_dups + 1`
		fi
	    done
	else
	    echo $sp/$mdl does not exist.
	fi
    done
done

#  Check for no files found.

if [ ! -s vsdb_files ]; then
    echo " "
    echo No files were found.  Check the control file.
    echo " "
   /bin/rm -f ymd.tbl vsdb_Ymd mklist.prl vsdb_files
    exit 1
fi

mv vsdb_files vsdb_files_found

if [ $icnt_dups -ne 0 ]; then
    echo " "
    echo "Duplicated files detected and removed from list; possible erroneous"
    echo "search conditions.  Check the control file."
    echo " "
   /bin/rm -f ymd.tbl vsdb_Ymd mklist.prl
    exit 1
fi
/bin/rm -f ymd.tbl vsdb_Ymd mklist.prl
