# @(#)Cshrc
#########################################################################
#  This script creates an fvs delivery file.				#
#									#
#									#
#  Log:									#
#  K. Brill/HPC  20061025  Created					#
#  K. Brill/HPC  20080205  Recovered from backup; make all exe tar fls  #
#  K. Brill/HPC  20090107  Remove hp from default opsyss list		#
#  K. Brill/HPC  20120404  Update opsyss list				#
#  K. Brill/HPC  20120731  Copy version_of_fvs file to tar directory	#
#  K. Brill/HPC  20130605  Copy exe files for wcoss rather than aix	#
#########################################################################
cd $VSDB
if ( $status != 0 ) then
    echo VSDB not found.
    exit 1
endif

if ( ${?DDAPP} == 0 ) then
    echo DDAPP is not set.
    exit 2
endif

if ( ${#argv} > 0 ) then
    set opsyss = $1
    if ( ! -d $DDAPP/exe_$opsyss ) then
	echo $opsyss is not a valid operating system.
	exit 3
    endif
else
    set opsyss = (wcoss lnx5 lnx6)
endif

mkdir $HOME/vfvs_tar
cp version_of_fvs $HOME/vfvs_tar/.

cat << 'EOF' > $HOME/vfvs_tar/vfvs_README4tar

The fvs tar balls allow you to install fvs under your own account.  You will
have to modify your .profile and/or .cshrc files.  Here is what to do:

  1. Create a directory under your user ID (e.g., /u/xx) called vsdb, and
     execute "cd vsdb".
  2. Unzip the downloaded file named vfvs_soft.tar.gz and untar it in the vsdb
     directory.  Use options -xpvf on the tar command.
     If this is a first-time installation, execute "mv d_scripts scripts";
     otherwise, copy only scripts that have changed from d_scripts into scripts.
     Be careful not to copy scripts you modified in an earlier installation,
     see step 7. below.  You may need to modify your version of these scripts.
  3. Create a directory called vsdb_exe on a permanent disk where you have a
     lot of space.
  4. Unzip the downloaded file named vfvs_exe_SYS.tar.gz and untar it in the
     vsdb_exe directory.  SYS is replaced with the name of the operating system.
  5. Do the following in your .cshrc (or .profile, with ksh syntax):
        1) Add vsdb_exe directory to your path
        2) Set environment variable VSDB to /u/xx/vsdb
        3) Set environment variable VSDB_DATA to point at your VSDB data
        4) source /u/xx/vsdb/scripts/for_fvs
           (ksh: . /u/xx/vsdb/scripts/for_fvs.sh)
  6. Log out and log back in to test.
  7. If fvs does not work, you may have to modify for_fvs and/or for_fvs.sh.
  8. Modify the "set_vsdb_data2" scripts if you want to have correct interactive
     choices for multiple VSDB data paths in fvs.  This is optional.

This assumes you have GEMPAK installed and GEMPAK environment variables set;
although, you will not need GEMPAK if you specify only DEVICE=TX (text) for
graphics output.

For complete information, enter "fvs h" to print the help file.

'EOF'

cp $HOME/vfvs_tar/vfvs_README4tar .

cp -r scripts d_scripts
tar cpvf $HOME/vfvs_tar/vfvs_soft.tar vfvs_README4tar version_of_fvs help d_scripts tables doc/script_guide
/bin/rm -r d_scripts
tar cvf $HOME/vfvs_tar/vfvs_code.tar source

/bin/rm -f $HOME/vfvs_tar/vfvs_soft.tar.gz
/bin/rm -f $HOME/vfvs_tar/vfvs_code.tar.gz
gzip $HOME/vfvs_tar/vfvs_soft.tar
gzip $HOME/vfvs_tar/vfvs_code.tar

foreach opsys ($opsyss)

    cd $DDAPP/exe_$opsys
    if ( $status != 0 ) then
        echo DDAPP not found.
        continue
    endif

    tar cvf $HOME/vfvs_tar/vfvs_exe_$opsys.tar version_of_fvs mkflnm_vsdb mkplot_vsdb mktlst_vsdb mktrcs_vsdb mkvsdb_vsdb mkymrg_vsdb

    /bin/rm -f $HOME/vfvs_tar/vfvs_exe_$opsys.tar.gz
    gzip $HOME/vfvs_tar/vfvs_exe_$opsys.tar

end
